# @Description  : https://www.cnblogs.com/dachenzi/p/8242713.html

# http://docs.jinkan.org/docs/jinja2/
# https://blog.csdn.net/weixin_43067754/article/details/88046471
# https://www.jianshu.com/p/f04dae701361


# 去除模板下的__pycache__文件夹

![image-20211104094258324](https://tva1.sinaimg.cn/large/008i3skNgy1gw2vgq5sm4j31jc0rytbf.jpg)